@@ -35,7 +35,7 @@ public slots:
     /** @brief Add a keyframe with given parameter value at given pos.
        If pos is negative, then keyframe is added at current position
     */
-    void slotAddKeyframe(int pos = -1);
+    bool slotAddKeyframe(int pos = -1);
     /** @brief Duplicate selected keyframe at cursor position
     */
     void slotDuplicateKeyframe();
