@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2016 by Nicolas Carion                                  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2016 Nicolas Carion
+
+SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "abstractparamwidget.hpp"
 #include "assets/model/assetparametermodel.hpp"
@@ -34,6 +21,7 @@
 #include "hideparamwidget.hpp"
 #include "keyframewidget.hpp"
 #include "listparamwidget.h"
+#include "listdependencyparamwidget.h"
 #include "lumaliftgainparam.hpp"
 #include "positioneditwidget.hpp"
 #include "slidewidget.hpp"
@@ -85,6 +73,9 @@ AbstractParamWidget *AbstractParamWidget::construct(const std::shared_ptr<AssetP
     case ParamType::Double:
         widget = new DoubleParamWidget(model, index, parent);
         break;
+    case ParamType::ListWithDependency:
+        widget = new ListDependencyParamWidget(model, index, parent);
+        break;
     case ParamType::List:
         widget = new ListParamWidget(model, index, parent);
         break;
@@ -97,6 +88,7 @@ AbstractParamWidget *AbstractParamWidget::construct(const std::shared_ptr<AssetP
     case ParamType::KeyframeParam:
     case ParamType::AnimatedRect:
     case ParamType::Roto_spline:
+    case ParamType::ColorWheel:
         widget = new KeyframeWidget(model, index, frameSize, parent);
         break;
     case ParamType::Geometry:
@@ -108,9 +100,6 @@ AbstractParamWidget *AbstractParamWidget::construct(const std::shared_ptr<AssetP
     case ParamType::Color:
         widget = new ColorEditWidget(model, index, parent);
         break;
-    case ParamType::ColorWheel:
-        widget = new LumaLiftGainParam(model, index, parent);
-        break;
     case ParamType::Wipe:
         widget = new SlideWidget(model, index, parent);
         break;
