@@ -1,23 +1,7 @@
-/***************************************************************************
- *   Copyright (C) 2017 by Nicolas Carion                                  *
- *   This file is part of Kdenlive. See www.kdenlive.org.                  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) version 3 or any later version accepted by the       *
- *   membership of KDE e.V. (or its successor approved  by the membership  *
- *   of KDE e.V.), which shall act as a proxy defined in Section 14 of     *
- *   version 3 of the license.                                             *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2017 Nicolas Carion
+    SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "clipcreator.hpp"
 #include "bin/bin.h"
@@ -70,7 +54,7 @@ QString ClipCreator::createTitleClip(const std::unordered_map<QString, QString>
 
     QString id;
     std::function<void(const QString &)> callBack = [](const QString &binId) {
-        pCore->bin()->selectClipById(binId);
+        pCore->activeBin()->selectClipById(binId);
     };
     bool res = model->requestAddBinClip(id, xml.documentElement(), parentFolder, i18n("Create title clip"), callBack);
     return res ? id : QStringLiteral("-1");
@@ -85,7 +69,7 @@ QString ClipCreator::createColorClip(const QString &color, int duration, const Q
 
     QString id;
     std::function<void(const QString &)> callBack = [](const QString &binId) {
-        pCore->bin()->selectClipById(binId);
+        pCore->activeBin()->selectClipById(binId);
     };
     bool res = model->requestAddBinClip(id, xml.documentElement(), parentFolder, i18n("Create color clip"), callBack);
     return res ? id : QStringLiteral("-1");
@@ -184,7 +168,7 @@ QString ClipCreator::createSlideshowClip(const QString &path, int duration, cons
 
     QString id;
     std::function<void(const QString &)> callBack = [](const QString &binId) {
-        pCore->bin()->selectClipById(binId);
+        pCore->activeBin()->selectClipById(binId);
     };
     bool res = model->requestAddBinClip(id, xml.documentElement(), parentFolder, i18n("Create slideshow clip"), callBack);
     return res ? id : QStringLiteral("-1");
@@ -220,7 +204,7 @@ QString ClipCreator::createTitleTemplate(const QString &path, const QString &tex
 
     QString id;
     std::function<void(const QString &)> callBack = [](const QString &binId) {
-        pCore->bin()->selectClipById(binId);
+        pCore->activeBin()->selectClipById(binId);
     };
     bool res = model->requestAddBinClip(id, xml.documentElement(), parentFolder, i18n("Create title template"), callBack);
     return res ? id : QStringLiteral("-1");
@@ -263,7 +247,7 @@ const QString ClipCreator::createClipsFromList(const QList<QUrl> &list, bool che
     bool created = false;
     QMimeDatabase db;
     bool removableProject = checkRemovable ? isOnRemovableDevice(pCore->currentDoc()->projectDataFolder()) : false;
-    for (const QUrl &file : cleanList) {
+    for (const QUrl &file : qAsConst(cleanList)) {
         if (!QFile::exists(file.toLocalFile())) {
             continue;
         }
@@ -312,11 +296,16 @@ const QString ClipCreator::createClipsFromList(const QList<QUrl> &list, bool che
                     }
                 }
                 if (!sublist.isEmpty()) {
-                    // Create main folder
-                    bool folderCreated = pCore->projectItemModel()->requestAddFolder(folderId, dir.dirName(), parentFolder, local_undo, local_redo);
-                    if (!folderCreated) {
-                        continue;
+                    if (!KdenliveSettings::ignoresubdirstructure() || topLevel) {
+                        // Create main folder
+                        bool folderCreated = pCore->projectItemModel()->requestAddFolder(folderId, dir.dirName(), parentFolder, local_undo, local_redo);
+                        if (!folderCreated) {
+                            continue;
+                        }
+                    } else {
+                        folderId = parentFolder;
                     }
+
                     createdItem = folderId;
                     // load subfolders
                     const QString clipId = createClipsFromList(sublist, checkRemovable, folderId, model, undo, redo, false);
@@ -325,10 +314,14 @@ const QString ClipCreator::createClipsFromList(const QList<QUrl> &list, bool che
                     }
                 }
             } else {
-                // Create main folder
-                bool folderCreated = pCore->projectItemModel()->requestAddFolder(folderId, dir.dirName(), parentFolder, local_undo, local_redo);
-                if (!folderCreated) {
-                    continue;
+                if (!KdenliveSettings::ignoresubdirstructure() || topLevel) {
+                    // Create main folder
+                    bool folderCreated = pCore->projectItemModel()->requestAddFolder(folderId, dir.dirName(), parentFolder, local_undo, local_redo);
+                    if (!folderCreated) {
+                        continue;
+                    }
+                } else {
+                    folderId = parentFolder;
                 }
                 createdItem = folderId;
                 const QString clipId = createClipsFromList(folderFiles, checkRemovable, folderId, model, local_undo, local_redo, false);
@@ -368,7 +361,7 @@ const QString ClipCreator::createClipsFromList(const QList<QUrl> &list, bool che
             std::function<void(const QString &)> callBack = [](const QString &) {};
             if (firstClip) {
                 callBack = [](const QString &binId) {
-                    pCore->bin()->selectClipById(binId);
+                    pCore->activeBin()->selectClipById(binId);
                 };
                 firstClip = false;
             }
