@@ -142,7 +142,7 @@ void SubtitleModel::importSubtitle(const QString filePath, int offset, bool exte
         srtFile.close();
     } else if (filePath.endsWith(QLatin1String(".ass"))) {
         qDebug()<< "ass File";
-        QString startTime,endTime,text;
+        QString startTime,endTime;
         QString EventFormat, section;
         turn = 0;
         int maxSplit =0;
@@ -158,6 +158,7 @@ void SubtitleModel::importSubtitle(const QString filePath, int offset, bool exte
         scriptInfoSection.clear();
         styleSection.clear();
         eventSection.clear();
+        int textIndex = 9;
         while (stream.readLineInto(&line)) {
             line = line.simplified();
             if (!line.isEmpty()) {
@@ -209,8 +210,8 @@ void SubtitleModel::importSubtitle(const QString filePath, int offset, bool exte
                     QStringList format;
                     if (line.contains("Format:")) {
                     	eventSection += line +"\n";
-                        EventFormat += line;
-                        format = (EventFormat.split(": ")[1].replace(" ","")).split(',');
+                        EventFormat += line.toLower().simplified().remove(QLatin1Char(' '));
+                        format = EventFormat.split(":")[1].split(QLatin1Char(','));
                         //qDebug() << format << format.count();
                         maxSplit = format.count();
                         //TIME
@@ -219,26 +220,23 @@ void SubtitleModel::importSubtitle(const QString filePath, int offset, bool exte
                         if (maxSplit > 3)
                             endTime = format.at(2);
                         // Text
-                        if (maxSplit > 9)
-                            text = format.at(9);
-                        //qDebug()<< startTime << endTime << text;
+                        if (format.contains(QStringLiteral("text"))) {
+                            textIndex = format.indexOf(QStringLiteral("text"));
+                        }
                     } else {
-                        QString EventDialogue;
-                        QStringList dialogue;
-                        start = "";end = "";comment = "";
-                        EventDialogue += line;
-                        dialogue = EventDialogue.split(": ")[1].split(',');
-                        if (dialogue.count() > 9) {
-                            QString remainingStr = "," + EventDialogue.split(": ")[1].section(',', maxSplit);
-                            //qDebug()<< dialogue;
+                        start.clear();
+                        end.clear();
+                        comment.clear();
+                        QStringList dialogue = line.section(":", 1).split(QLatin1Char(','));
+                        if (dialogue.count() >= textIndex) {
                             //TIME
                             start = dialogue.at(1);
                             startPos= stringtoTime(start);
                             end = dialogue.at(2);
                             endPos= stringtoTime(end);
                             // Text
-                            comment = dialogue.at(9)+ remainingStr;
-                            //qDebug()<<"Start: "<< start << "End: "<<end << comment;
+                            comment = dialogue.at(textIndex);
+                            // qDebug()<<"Start: "<< start << "End: "<<end << comment;
                             if (endPos > startPos) {
                                 addSubtitle(startPos + subtitleOffset, endPos + subtitleOffset, comment, undo, redo, false);
                             } else {
@@ -250,7 +248,7 @@ void SubtitleModel::importSubtitle(const QString filePath, int offset, bool exte
                 turn++;
             } else {
                 turn = 0;
-                text = startTime = endTime = "";
+                startTime = endTime = QString();
             }
         }
         assFile.close();
@@ -488,7 +486,7 @@ std::unordered_set<int> SubtitleModel::getItemsInRange(int startFrame, int endFr
             // Outside range
             continue;
         }
-        if (subtitles.first >= startTime || subtitles.second.second >= startTime) {
+        if (subtitles.first >= startTime || subtitles.second.second > startTime) {
             int sid = getIdForStartPos(subtitles.first);
             if (sid > -1) {
                 matching.emplace(sid);
@@ -504,7 +502,7 @@ bool SubtitleModel::cutSubtitle(int position)
 {
     Fun redo = []() { return true; };
     Fun undo = []() { return true; };
-    if (cutSubtitle(position, undo, redo)) {
+    if (cutSubtitle(position, undo, redo) > -1) {
         pCore->pushUndo(undo, redo, i18n("Cut clip"));
         return true;
     }
@@ -1206,36 +1204,30 @@ QDomElement SubtitleModel::toXml(int sid, QDomDocument &document)
     return container;
 }
 
-
-int SubtitleModel::getBlankSizeAtPos(int pos) const
+bool SubtitleModel::isBlankAt(int pos) const
 {
     GenTime matchPos(pos, pCore->getCurrentFps());
-    std::unordered_set<int> matching;
-    GenTime min;
-    GenTime max;
     for (const auto &subtitles : m_subtitleList) {
-        if (subtitles.first > matchPos && (max == GenTime() ||  subtitles.first < max)) {
-            // Outside range
-            max = subtitles.first;
+        if (subtitles.first > matchPos) {
+            continue;
         }
-        if (subtitles.second.second < matchPos && (min == GenTime() ||  subtitles.second.second > min)) {
-            min = subtitles.second.second;
+        if (subtitles.second.second > matchPos) {
+            return false;
         }
     }
-    return max.frames(pCore->getCurrentFps()) - min.frames(pCore->getCurrentFps());
+    return true;;
 }
 
 int SubtitleModel::getBlankStart(int pos) const
 {
     GenTime matchPos(pos, pCore->getCurrentFps());
-    std::unordered_set<int> matching;
     bool found = false;
     GenTime min;
     for (const auto &subtitles : m_subtitleList) {
-        if (subtitles.second.second < matchPos && (min == GenTime() ||  subtitles.second.second > min)) {
+        if (subtitles.second.second <= matchPos && (min == GenTime() ||  subtitles.second.second > min)) {
             min = subtitles.second.second;
             found = true;
         }
     }
-    return found ? min.frames(pCore->getCurrentFps()) + 1 : 0;
+    return found ? min.frames(pCore->getCurrentFps()) : 0;
 }
