@@ -16,6 +16,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #include <QFuture>
 #include <QMutex>
+#include <QTimer>
 #include <memory>
 
 class ClipPropertiesController;
@@ -231,6 +232,8 @@ public:
     int getRecordTime();
     /** @brief Return maximum audio level for a stream. */
     int getAudioMax(int stream);
+    /** @brief Refresh zones of insertion in timeline. */
+    void refreshBounds();
 
 protected:
     friend class ClipModel;
@@ -247,7 +250,7 @@ protected:
     /** @brief This is a call-back called by a ClipModel when it is deleted
         @param clipId id of the deleted clip
     */
-    void deregisterTimelineClip(int clipId);
+    void deregisterTimelineClip(int clipId, bool audioClip);
 
     void emitProducerChanged(const QString &id, const std::shared_ptr<Mlt::Producer> &producer) override { emit producerChanged(id, producer); };
     void replaceInTimeline();
@@ -287,6 +290,8 @@ public slots:
     bool setProducer(std::shared_ptr<Mlt::Producer> producer);
     
     void importJsonMarkers(const QString &json);
+    /** @brief Refresh zones of insertion in timeline. */
+    void checkClipBounds();
 
 private:
     /** @brief Generate and store file hash if not available. */
@@ -302,6 +307,8 @@ private:
     void createDisabledMasterProducer();
 
     std::map<int, std::weak_ptr<TimelineModel>> m_registeredClips;
+    uint m_audioCount;
+    QTimer m_boundaryTimer;
 
     /** @brief the following holds a producer for each audio clip in the timeline
      * keys are the id of the clips in the timeline, values are their values */
@@ -320,6 +327,8 @@ signals:
     void loadPropertiesPanel();
     void audioThumbReady();
     void updateStreamInfo(int ix);
+    void boundsChanged(QVector <QPoint>bounds);
+    void registeredClipChanged();
 };
 
 #endif
