@@ -1,19 +1,7 @@
-/***************************************************************************
-                        mltdevicecapture.h  -  description
-                           -------------------
-  begin                : Sun May 21 2011
-  copyright            : (C) 2011 by Jean-Baptiste Mardelle (jb@kdenlive.org)
-
-***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+   SPDX-FileCopyrightText: 2011 Jean-Baptiste Mardelle <jb@kdenlive.org>
+   SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #ifndef MLTDEVICECAPTURE_H
 #define MLTDEVICECAPTURE_H
