@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2008 by Jean-Baptiste Mardelle (jb@kdenlive.org)        *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Jean-Baptiste Mardelle <jb@kdenlive.org>
+
+SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "proxytest.h"
 
@@ -59,7 +46,7 @@ ProxyTest::ProxyTest(QWidget *parent)
             paramBox->setVisible(false);
         }
     });
-    connect(buttonBox->button(QDialogButtonBox::Apply), &QPushButton::clicked, [this]() {
+    connect(buttonBox->button(QDialogButtonBox::Apply), &QPushButton::clicked, this, [this]() {
         infoWidget->setText(i18n("Starting process"));
         infoWidget->animatedShow();
         resultList->setCursor(Qt::BusyCursor);
@@ -125,11 +112,11 @@ void ProxyTest::startTest()
     QTemporaryFile src(QDir::temp().absoluteFilePath(QString("XXXXXX.mov")));
     if (!src.open()) {
         // Something went wrong
-        QMetaObject::invokeMethod(this, "showMessage", Qt::QueuedConnection, Q_ARG(const QString&,i18n("Cannot create temporary files")));
+        QMetaObject::invokeMethod(this, "showMessage", Qt::QueuedConnection, Q_ARG(QString,i18n("Cannot create temporary files")));
         return;
     }
     m_process.reset(new QProcess());
-    QMetaObject::invokeMethod(this, "showMessage", Qt::QueuedConnection, Q_ARG(const QString&,i18n("Generating a 60 seconds test video %1", src.fileName())));
+    QMetaObject::invokeMethod(this, "showMessage", Qt::QueuedConnection, Q_ARG(QString,i18n("Generating a 60 seconds test video %1", src.fileName())));
     QStringList source = {QStringLiteral("-y"),QStringLiteral("-f"),QStringLiteral("lavfi"),QStringLiteral("-i"),QStringLiteral("testsrc=duration=60:size=1920x1080:rate=25"),QStringLiteral("-c:v"),QStringLiteral("libx264"),QStringLiteral("-pix_fmt"),QStringLiteral("yuv420p"),src.fileName()};
     m_process->start(KdenliveSettings::ffmpegpath(), source);
     m_process->waitForStarted();
@@ -140,14 +127,14 @@ void ProxyTest::startTest()
         QMutexLocker lk(&m_locker);
         k.next();
         if (!k.key().isEmpty()) {
-            QMetaObject::invokeMethod(this, "showMessage", Qt::QueuedConnection, Q_ARG(const QString&,i18n("Processing %1", k.key())));
+            QMetaObject::invokeMethod(this, "showMessage", Qt::QueuedConnection, Q_ARG(QString,i18n("Processing %1", k.key())));
             QString params = k.value().section(QLatin1Char(';'), 0, 0);
             QString extension = k.value().section(QLatin1Char(';'), 1, 1);
             // Testing vaapi support
             QTemporaryFile tmp(QDir::temp().absoluteFilePath(QString("XXXXXX.%1").arg(extension)));
             if (!tmp.open()) {
                 // Something went wrong
-                QMetaObject::invokeMethod(this, "showMessage", Qt::QueuedConnection, Q_ARG(const QString&,i18n("Cannot create temporary files")));
+                QMetaObject::invokeMethod(this, "showMessage", Qt::QueuedConnection, Q_ARG(QString,i18n("Cannot create temporary files")));
                 return;
             }
             tmp.close();
@@ -197,13 +184,13 @@ void ProxyTest::startTest()
                 qDebug()<<"==== PROFILE FAILED: "<<k.key()<<" !!!!!!!!!!!!";
                 results << QStringList({k.key()});
             }
-            QMetaObject::invokeMethod(this, "addAnalysis", Qt::QueuedConnection, Q_ARG(const QStringList&,results));
+            QMetaObject::invokeMethod(this, "addAnalysis", Qt::QueuedConnection, Q_ARG(QStringList,results));
         }
         if (m_closing) {
             return;
         }
     }
-    QMetaObject::invokeMethod(this, "showMessage", Qt::QueuedConnection, Q_ARG(const QString&,QString()));
+    QMetaObject::invokeMethod(this, "showMessage", Qt::QueuedConnection, Q_ARG(QString,QString()));
 }
 
 
