@@ -311,15 +311,20 @@ void RemapView::loadKeyframes(const QString &mapData)
             m_duration = qMax(m_duration, pos - m_inFrame);
             m_duration = qMax(m_duration, val - m_inFrame);
         }
-
+        bool isKfr = m_keyframes.contains(m_bottomPosition + m_inFrame);
+        if (isKfr) {
+            bool isLast = m_bottomPosition + m_inFrame == m_keyframes.firstKey() || m_bottomPosition + m_inFrame == m_keyframes.lastKey();
+            emit atKeyframe(isKfr, isLast);
+        } else {
+            emit atKeyframe(false, false);
+        }
         if (m_keyframes.contains(m_currentKeyframe.first)) {
-            bool isLast = m_currentKeyframe.first == m_keyframes.firstKey() || m_currentKeyframe.first == m_keyframes.lastKey();
-            emit atKeyframe(true, isLast);
+            //bool isLast = m_currentKeyframe.first == m_keyframes.firstKey() || m_currentKeyframe.first == m_keyframes.lastKey();
+            //emit atKeyframe(true, isLast);
             std::pair<double,double>speeds = getSpeed(m_currentKeyframe);
             std::pair<bool,bool> atEnd = {m_currentKeyframe.first == m_inFrame, m_currentKeyframe.first == m_keyframes.lastKey()};
             emit selectedKf(m_currentKeyframe, speeds, atEnd);
         } else {
-            emit atKeyframe(false, false);
             m_currentKeyframe = {-1,-1};
             emit selectedKf(m_currentKeyframe, {-1,-1} );
         }
@@ -1126,10 +1131,10 @@ void RemapView::goPrev()
 void RemapView::updateBeforeSpeed(double speed)
 {
     QMutexLocker lock(&m_kfrMutex);
-    QMap<int, int>::iterator it = m_keyframes.find(m_currentKeyframe.first);
+    QMap<int, int>::const_iterator it = m_keyframes.constFind(m_currentKeyframe.first);
     QMap<int, int> updatedKfrs;
     QList<int> toDelete;
-    if (*it != m_keyframes.first() && it != m_keyframes.end()) {
+    if (*it != m_keyframes.first() && it != m_keyframes.constEnd()) {
         m_keyframesOrigin = m_keyframes;
         it--;
         int updatedLength = qFuzzyIsNull(speed) ? 0 : (m_currentKeyframe.second - it.value()) * 100. / speed;
@@ -1140,11 +1145,11 @@ void RemapView::updateBeforeSpeed(double speed)
         m_bottomPosition = m_currentKeyframe.first;
         m_selectedKeyframes.clear();
         m_selectedKeyframes.insert(m_currentKeyframe.first, m_currentKeyframe.second);
-        it++;
+        it = m_keyframes.constFind(m_currentKeyframe.first);
         if (*it != m_keyframes.last()) {
             it++;
             // Update all keyframes after that so that we don't alter the speeds
-            while (m_moveNext && it != m_keyframes.end()) {
+            while (m_moveNext && it != m_keyframes.constEnd()) {
                 toDelete << it.key();
                 updatedKfrs.insert(it.key() + offset, it.value());
                 it++;
@@ -1170,7 +1175,7 @@ void RemapView::updateBeforeSpeed(double speed)
 void RemapView::updateAfterSpeed(double speed)
 {
     QMutexLocker lock(&m_kfrMutex);
-    QMap<int, int>::iterator it = m_keyframes.find(m_currentKeyframe.first);
+    QMap<int, int>::const_iterator it = m_keyframes.constFind(m_currentKeyframe.first);
     if (*it != m_keyframes.last()) {
         m_keyframesOrigin = m_keyframes;
         it++;
@@ -1179,7 +1184,7 @@ void RemapView::updateAfterSpeed(double speed)
         int updatedLength = qFuzzyIsNull(speed) ? 0 : (it.value() - m_currentKeyframe.second) * 100. / speed;
         int offset = m_currentKeyframe.first + updatedLength - it.key();
         if (m_moveNext) {
-            while (it != m_keyframes.end()) {
+            while (it != m_keyframes.constEnd()) {
                 toDelete << it.key();
                 updatedKfrs.insert(it.key() + offset, it.value());
                 it++;
@@ -1981,6 +1986,7 @@ void TimeRemap::updateKeyframesWithUndo(QMap<int,int>updatedKeyframes, QMap<int,
         }
         return true;
     };
+    local_redo();
     if (durationChanged) {
         int length = updatedKeyframes.lastKey() - m_view->m_inFrame + 1;
         std::shared_ptr<TimelineItemModel> model = pCore->window()->getCurrentTimeline()->controller()->getModel();
@@ -1989,7 +1995,6 @@ void TimeRemap::updateKeyframesWithUndo(QMap<int,int>updatedKeyframes, QMap<int,
             model->requestItemResize(m_splitId, length, true, true, undo, redo);
         }
     }
-    local_redo();
     UPDATE_UNDO_REDO_NOLOCK(redo, undo, local_undo, local_redo);
     pCore->pushUndo(local_undo, local_redo, i18n("Edit Timeremap keyframes"));
 }
