@@ -42,6 +42,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #if KIO_VERSION >= QT_VERSION_CHECK(5,71,0)
 #include <KIO/OpenUrlJob>
+#include <KIO/JobUiDelegate>
 #endif
 
 // Recommended MLT version
@@ -125,8 +126,18 @@ Wizard::Wizard(bool autoClose, bool appImageCheck, QWidget *parent)
         lab->setText(i18n("Startup error or warning, check our <a href='#'>online manual</a>."));
         connect(lab, &QLabel::linkActivated, this, &Wizard::slotOpenManual);
         m_startLayout->addWidget(lab);
-    } else {
-        // Everything is ok, auto close the wizard
+    }
+    if (!m_infos.isEmpty()) {
+        auto *errorLabel = new KMessageWidget(this);
+        errorLabel->setText(QStringLiteral("<ul>") + m_infos + QStringLiteral("</ul>"));
+        errorLabel->setMessageType(KMessageWidget::Information);
+        errorLabel->setWordWrap(true);
+        errorLabel->setCloseButtonVisible(false);
+        m_startLayout->addWidget(errorLabel);
+        errorLabel->show();
+    }
+    if (m_errors.isEmpty() && m_warnings.isEmpty()) {
+        // Everything is ok only some info message, show codec status
         m_page->setComplete(true);
         if (autoClose) {
             QTimer::singleShot(0, this, &QDialog::accept);
@@ -184,15 +195,6 @@ Wizard::Wizard(bool autoClose, bool appImageCheck, QWidget *parent)
         m_startLayout->addWidget(errorLabel);
         errorLabel->show();
     }
-    if (!m_infos.isEmpty()) {
-        auto *errorLabel = new KMessageWidget(this);
-        errorLabel->setText(QStringLiteral("<ul>") + m_infos + QStringLiteral("</ul>"));
-        errorLabel->setMessageType(KMessageWidget::Information);
-        errorLabel->setWordWrap(true);
-        errorLabel->setCloseButtonVisible(false);
-        m_startLayout->addWidget(errorLabel);
-        errorLabel->show();
-    }
     // build profiles lists
     /*QMap<QString, QString> profilesInfo = ProfilesDialog::getProfilesInfo();
     QMap<QString, QString>::const_iterator i = profilesInfo.constBegin();
@@ -631,8 +633,6 @@ void Wizard::checkMissingCodecs()
 
 void Wizard::slotCheckPrograms(QString &infos, QString &warnings)
 {
-    bool allIsOk = true;
-
     // Check first in same folder as melt exec
     const QStringList mltpath({QFileInfo(KdenliveSettings::rendererpath()).canonicalPath(), qApp->applicationDirPath()});
     QString exepath;
@@ -647,7 +647,6 @@ void Wizard::slotCheckPrograms(QString &infos, QString &warnings)
             exepath = QStandardPaths::findExecutable(QStringLiteral("avconv"));
             if (exepath.isEmpty()) {
                 warnings.append(i18n("<li>Missing app: <b>ffmpeg</b><br/>required for proxy clips and transcoding</li>"));
-                allIsOk = false;
             }
         }
     }
@@ -721,10 +720,29 @@ void Wizard::slotCheckPrograms(QString &infos, QString &warnings)
             KdenliveSettings::setDefaultaudioapp(program);
         }
     }
-    if (allIsOk) {
-        // OK
-    } else {
-        // WRONG
+
+    if (KdenliveSettings::defaultaudioapp().isEmpty()) {
+        program = QStandardPaths::findExecutable(QStringLiteral("audacity"));
+        if (program.isEmpty()) {
+            program = QStandardPaths::findExecutable(QStringLiteral("traverso"));
+        }
+        if (!program.isEmpty()) {
+            KdenliveSettings::setDefaultaudioapp(program);
+        }
+    }
+
+    if (KdenliveSettings::mediainfopath().isEmpty() || !QFileInfo::exists(KdenliveSettings::mediainfopath())) {
+        program = QStandardPaths::findExecutable(QStringLiteral("mediainfo"));
+#ifdef Q_OS_WIN
+        if (program.isEmpty()) {
+            program = QStandardPaths::findExecutable(QStringLiteral("mediainfo"), {"C:/Program Files/MediaInfo", "C:/Program Files (x86)/MediaInfo"});
+        }
+#endif
+        if (program.isEmpty()) {
+            infos.append(i18n("<li>Missing app: <b>mediainfo</b><br/>optional for technical clip information</li>"));
+        } else {
+            KdenliveSettings::setMediainfopath(program);
+        }
     }
 }
 
@@ -924,9 +942,14 @@ bool Wizard::isOk() const
 void Wizard::slotOpenManual()
 {
 #if KIO_VERSION >= QT_VERSION_CHECK(5,71,0)
-    KIO::OpenUrlJob(QUrl(QStringLiteral("https://kdenlive.org/troubleshooting")), QStringLiteral("text/html"));
+    auto *job = new KIO::OpenUrlJob(QUrl(QStringLiteral("https://docs.kdenlive.org/troubleshooting/installation_troubleshooting.html")));
+    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+    // methods like setRunExecutables, setSuggestedFilename, setEnableExternalBrowser, setFollowRedirections
+    // exist in both classes
+    job->start();
+    //KIO::OpenUrlJob(QUrl(QStringLiteral("https://docs.kdenlive.org/troubleshooting/installation_troubleshooting.html")), QStringLiteral("text/html"));
 #else
-    KRun::runUrl(QUrl(QStringLiteral("https://kdenlive.org/troubleshooting")), QStringLiteral("text/html"), this, KRun::RunFlags());
+    KRun::runUrl(QUrl(QStringLiteral("https://docs.kdenlive.org/troubleshooting/installation_troubleshooting.html")), QStringLiteral("text/html"), this, KRun::RunFlags());
 #endif
 }
 
