@@ -1,22 +1,8 @@
-/***************************************************************************
- *                                                                         *
- *   Copyright (C) 2011 by Jean-Baptiste Mardelle (jb@kdenlive.org)        *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2011 Jean-Baptiste Mardelle <jb@kdenlive.org>
+
+SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "filtertask.h"
 #include "bin/bin.h"
@@ -70,8 +56,7 @@ void FilterTask::run()
     
     QString url;
     auto binClip = pCore->projectItemModel()->getClipByBinID(m_binId);
-    std::unique_ptr<Mlt::Producer> producer;
-    //std::unique_ptr<Mlt::Producer> wholeProducer;
+    std::unique_ptr<Mlt::Producer> producer = nullptr;
     Mlt::Profile profile(pCore->getCurrentProfilePath().toUtf8().constData());
     if (binClip) {
         // Filter applied on a timeline or bin clip
@@ -105,8 +90,6 @@ void FilterTask::run()
         }
         if (m_inPoint != 0 || m_outPoint != producer->get_length() - 1) {
             producer->set_in_and_out(m_inPoint, m_outPoint);
-            //std::swap(wholeProducer, producer);
-            //producer.reset(wholeProducer->cut(m_inPoint, m_outPoint));
         }
     } else {
         // Filter applied on a track of master producer, leave config to source job
@@ -118,14 +101,13 @@ void FilterTask::run()
         }
     }
     
-    if ((producer == nullptr) || !producer->is_valid()) {
+    if (producer == nullptr || !producer->is_valid()) {
         // Clip was removed or something went wrong, Notify user?
         QMetaObject::invokeMethod(pCore.get(), "displayBinMessage", Qt::QueuedConnection, Q_ARG(QString, i18n("Cannot open source.")),
                                   Q_ARG(int, int(KMessageWidget::Warning)));
         pCore->taskManager.taskDone(m_owner.second, this);
         return;
     }
-    
     length = producer->get_playtime();
     if (length == 0) {
         length = producer->get_length();
@@ -154,7 +136,7 @@ void FilterTask::run()
 
     consumer->connect(*producer.get());
     producer->set_speed(0);
-    producer->seek(0);
+
     if (binClip) {
         // Build filter
         Mlt::Filter filter(profile, m_filterName.toUtf8().data());
@@ -169,6 +151,9 @@ void FilterTask::run()
         qDebug()<<" = = = = = CONFIGURING FILTER PARAMS = = = = =  ";
         for (const auto &it : m_filterParams) {
             qDebug()<<". . ."<<it.first<<" = "<<it.second;
+            if (it.first == QLatin1String("in") || it.first == QLatin1String("out")) {
+                continue;
+            }
             if (it.second.type() == QVariant::Double) {
                 filter.set(it.first.toUtf8().constData(), it.second.toDouble());
             } else {
@@ -178,7 +163,7 @@ void FilterTask::run()
         if (m_filterData.find(QLatin1String("relativeInOut")) != m_filterData.end()) {
             // leave it operate on full clip
         } else {
-            filter.set_in_and_out(producer->get_in(), producer->get_out());
+            filter.set_in_and_out(m_inPoint, m_outPoint);
         }
         producer->attach(filter);
         filter.set("id", "kdenlive-analysis");
@@ -219,7 +204,6 @@ void FilterTask::run()
     dom.clear();
 
     // Step 2: process the xml file and save in another .mlt file
-    QProcess filterProcess;
     QStringList args({QStringLiteral("progress=1"), sourceFile.fileName()});
     m_jobProcess.reset(new QProcess);
     QObject::connect(this, &AbstractTask::jobCanceled, m_jobProcess.get(), &QProcess::kill, Qt::DirectConnection);
@@ -259,18 +243,18 @@ void FilterTask::run()
         }
     }
 
-    params.append({key,QVariant(resultData)});
-    if (m_inPoint > 0 && (m_filterData.find(QLatin1String("relativeInOut")) != m_filterData.end())) {
-        // Motion tracker keyframes always start at master clip 0, so we need to set in/out points
+    if (m_inPoint > 0 && (m_filterData.find(QLatin1String("relativeInOut")) == m_filterData.end())) {
+        // Motion tracker keyframes always start at master clip 0, so no need to set in/out points
         params.append({QStringLiteral("in"), m_inPoint});
         params.append({QStringLiteral("out"), m_outPoint});
     }
+    params.append({key,QVariant(resultData)});
     if (m_filterData.find(QStringLiteral("storedata")) != m_filterData.end()) {
         // Store a copy of the data in clip analysis
         QString dataName = (m_filterData.find(QStringLiteral("displaydataname")) != m_filterData.end()) ? m_filterData.at(QStringLiteral("displaydataname")) : QStringLiteral("data");
         auto binClip = pCore->projectItemModel()->getClipByBinID(m_binId);
         if (binClip) {
-            QMetaObject::invokeMethod(binClip.get(), "updatedAnalysisData", Q_ARG(const QString&, dataName), Q_ARG(const QString&, resultData), Q_ARG(int, m_inPoint));
+            QMetaObject::invokeMethod(binClip.get(), "updatedAnalysisData", Q_ARG(QString, dataName), Q_ARG(QString, resultData), Q_ARG(int, m_inPoint));
         }
         //binClip->updatedAnalysisData(dataName, resultData, m_inPoint);
     }
@@ -293,7 +277,7 @@ void FilterTask::run()
         QMetaObject::invokeMethod(pCore.get(), "setDocumentModified");
         return true;
     };
-    bool ok = operation();
+    operation();
     return;
 }
 
