@@ -1,22 +1,8 @@
-/***************************************************************************
- *                                                                         *
- *   Copyright (C) 2021 by Jean-Baptiste Mardelle (jb@kdenlive.org)        *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2021 Jean-Baptiste Mardelle <jb@kdenlive.org>
+
+SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "speedtask.h"
 #include "bin/bin.h"
@@ -49,6 +35,7 @@ SpeedTask::SpeedTask(const ObjectId &owner, const QString &binId, const QString
 
 void SpeedTask::start(QObject* object, bool force)
 {
+    Q_UNUSED(object)
     std::vector<QString> binIds = pCore->bin()->selectedClipsIds(true);
     // Show config dialog
     QDialog d(qApp->activeWindow());
@@ -90,12 +77,17 @@ void SpeedTask::start(QObject* object, bool force)
     l->addWidget(&lab);
     l->addWidget(&speedInput);
     l->addWidget(&cb);
+    QCheckBox cb2(i18n("Add clip to \"Speed Change\" folder"), &d);
+    cb2.setChecked(KdenliveSettings::add_new_clip_to_folder());
+    l->addWidget(&cb2);
     l->addWidget(&buttonBox);
     d.connect(&buttonBox, &QDialogButtonBox::rejected, &d, &QDialog::reject);
     d.connect(&buttonBox, &QDialogButtonBox::accepted, &d, &QDialog::accept);
     if (d.exec() != QDialog::Accepted) {
         return;
     }
+    bool addToFolder = cb2.isChecked();
+    KdenliveSettings::setAdd_new_clip_to_folder(addToFolder);
     double speed = speedInput.value();
     bool warp_pitch = cb.isChecked();
     std::unordered_map<QString, QString> destinations; // keys are binIds, values are path to target files
@@ -157,6 +149,7 @@ void SpeedTask::start(QObject* object, bool force)
         if (task) {
             // Otherwise, start a filter thread.
             task->m_isForce = force;
+            task->m_addToFolder = addToFolder;
             pCore->taskManager.startTask(owner.second, task);
         }
     }
@@ -215,9 +208,9 @@ void SpeedTask::run()
     for (const auto &it : m_filterParams) {
         qDebug()<<". . ."<<it.first<<" = "<<it.second;
         if (it.second.type() == QVariant::Double) {
-            producerArgs << QString("%1=%2").arg(it.first).arg(it.second.toDouble());
+            producerArgs << QString("%1=%2").arg(it.first, QString::number(it.second.toDouble()));
         } else {
-            producerArgs << QString("%1=%2").arg(it.first).arg(it.second.toString());
+            producerArgs << QString("%1=%2").arg(it.first, it.second.toString());
         }
     }
 
@@ -244,7 +237,7 @@ void SpeedTask::run()
         return;
     }
 
-    QMetaObject::invokeMethod(pCore->bin(), "addProjectClipInFolder", Qt::QueuedConnection, Q_ARG(const QString&,m_destination), Q_ARG(const QString&,binClip->parent()->clipId()), Q_ARG(const QString&,i18n("Speed Change")));
+    QMetaObject::invokeMethod(pCore->bin(), "addProjectClipInFolder", Qt::QueuedConnection, Q_ARG(QString,m_destination), Q_ARG(QString,binClip->parent()->clipId()), Q_ARG(QString,m_addToFolder ? i18n("Speed Change") : QString()));
     return;
 }
 
