@@ -174,6 +174,10 @@ void ClipController::getInfoForProducer()
             path.prepend(pCore->currentDoc()->documentRoot());
             m_properties->set("resource", path.toUtf8().constData());
         }
+        if (QFileInfo(proxy).isRelative()) {
+            proxy.prepend(pCore->currentDoc()->documentRoot());
+            m_properties->set("kdenlive:proxy", proxy.toUtf8().constData());
+        }
         // This is a proxy producer, read original url from kdenlive property
         path = m_properties->get("kdenlive:originalurl");
         if (QFileInfo(path).isRelative()) {
@@ -636,6 +640,19 @@ const QSize ClipController::getFrameSize() const
     if (m_masterProducer == nullptr) {
         return QSize();
     }
+    if (m_usesProxy) {
+        int width = m_masterProducer->get_int("kdenlive:original.meta.media.width");
+        int height = m_masterProducer->get_int("kdenlive:original.meta.media.height");
+        if (width == 0) {
+            width = m_masterProducer->get_int("kdenlive:original.width");
+        }
+        if (height == 0) {
+            width = m_masterProducer->get_int("kdenlive:original.height");
+        }
+        if (width > 0 && height > 0) {
+            return QSize(width, height);
+        }
+    }
     int width = m_masterProducer->get_int("meta.media.width");
     if (width == 0) {
         width = m_masterProducer->get_int("width");
