@@ -1,27 +1,15 @@
-/***************************************************************************
- *   Copyright (C) 2007 by Jean-Baptiste Mardelle (jb@kdenlive.org)        *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Jean-Baptiste Mardelle <jb@kdenlive.org>
+
+SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "monitormanager.h"
 #include "core.h"
 #include "doc/kdenlivedoc.h"
 #include "kdenlivesettings.h"
 #include "mainwindow.h"
+#include "timeline2/view/timelinewidget.h"
 
 #include <mlt++/Mlt.h>
 
@@ -32,17 +20,26 @@
 #include "kdenlive_debug.h"
 #include <QObject>
 #include <dialogs/timeremap.h>
+#include <timeline2/view/timelinecontroller.h>
 
 const double MonitorManager::speedArray[6] = {1. ,1.5, 2., 3., 5.5, 10.};
 
 MonitorManager::MonitorManager(QObject *parent)
     : QObject(parent)
+    , m_activeMultiTrack(-1)
 
 {
     setupActions();
     refreshTimer.setSingleShot(true);
     refreshTimer.setInterval(200);
     connect(&refreshTimer, &QTimer::timeout, this, &MonitorManager::forceProjectMonitorRefresh);
+    connect(pCore.get(), &Core::monitorProfileUpdated, this, [&]() {
+        QAction *prog = pCore->window()->actionCollection()->action(QStringLiteral("mlt_progressive"));
+        if (prog) {
+            prog->setEnabled(!pCore->getProjectProfile()->progressive());
+            slotProgressivePlay(prog->isChecked());
+        }
+    });
 }
 
 QAction *MonitorManager::getAction(const QString &name)
@@ -286,40 +283,95 @@ void MonitorManager::slotForward(double speed)
 
 void MonitorManager::slotRewindOneFrame()
 {
-    if (m_activeMonitor == m_clipMonitor) {
-        m_clipMonitor->slotRewindOneFrame();
-    } else if (m_activeMonitor == m_projectMonitor) {
-        m_projectMonitor->slotRewindOneFrame();
+    if (pCore->activeTool() == ToolType::SlipTool) {
+        m_projectMonitor->slotTrimmingPos(-1);
+        pCore->window()->getCurrentTimeline()->model()->requestSlipSelection(-1, true);
+    } else if (isTrimming()) {
+        return;
+    } else {
+        if (m_activeMonitor == m_clipMonitor) {
+            m_clipMonitor->slotRewindOneFrame();
+        } else if (m_activeMonitor == m_projectMonitor) {
+            m_projectMonitor->slotRewindOneFrame();
+        }
     }
 }
 
 void MonitorManager::slotForwardOneFrame()
 {
-    if (m_activeMonitor == m_clipMonitor) {
-        m_clipMonitor->slotForwardOneFrame();
-    } else if (m_activeMonitor == m_projectMonitor) {
-        m_projectMonitor->slotForwardOneFrame();
+    if (pCore->activeTool() == ToolType::SlipTool) {
+        m_projectMonitor->slotTrimmingPos(1);
+        pCore->window()->getCurrentTimeline()->model()->requestSlipSelection(1, true);
+    } else if (isTrimming()) {
+        return;
+    } else {
+        if (m_activeMonitor == m_clipMonitor) {
+            m_clipMonitor->slotForwardOneFrame();
+        } else if (m_activeMonitor == m_projectMonitor) {
+            m_projectMonitor->slotForwardOneFrame();
+        }
     }
 }
 
 void MonitorManager::slotRewindOneSecond()
 {
-    if (m_activeMonitor == m_clipMonitor) {
-        m_clipMonitor->slotRewindOneFrame(qRound(pCore->getCurrentFps()));
-    } else if (m_activeMonitor == m_projectMonitor) {
-        m_projectMonitor->slotRewindOneFrame(qRound(pCore->getCurrentFps()));
+    if (pCore->activeTool() == ToolType::SlipTool) {
+        m_projectMonitor->slotTrimmingPos(-qRound(pCore->getCurrentFps()));
+        pCore->window()->getCurrentTimeline()->model()->requestSlipSelection(-qRound(pCore->getCurrentFps()), true);
+    } else if (isTrimming()) {
+        return;
+    } else {
+        if (m_activeMonitor == m_clipMonitor) {
+            m_clipMonitor->slotRewindOneFrame(qRound(pCore->getCurrentFps()));
+        } else if (m_activeMonitor == m_projectMonitor) {
+            m_projectMonitor->slotRewindOneFrame(qRound(pCore->getCurrentFps()));
+        }
     }
 }
 
 void MonitorManager::slotForwardOneSecond()
 {
-    if (m_activeMonitor == m_clipMonitor) {
-        m_clipMonitor->slotForwardOneFrame(qRound(pCore->getCurrentFps()));
-    } else if (m_activeMonitor == m_projectMonitor) {
-        m_projectMonitor->slotForwardOneFrame(qRound(pCore->getCurrentFps()));
+    if (pCore->activeTool() == ToolType::SlipTool) {
+        m_projectMonitor->slotTrimmingPos(qRound(pCore->getCurrentFps()));
+        pCore->window()->getCurrentTimeline()->model()->requestSlipSelection(qRound(pCore->getCurrentFps()), true);
+    } else if (isTrimming()) {
+        return;
+    } else {
+        if (m_activeMonitor == m_clipMonitor) {
+            m_clipMonitor->slotForwardOneFrame(qRound(pCore->getCurrentFps()));
+        } else if (m_activeMonitor == m_projectMonitor) {
+            m_projectMonitor->slotForwardOneFrame(qRound(pCore->getCurrentFps()));
+        }
     }
 }
 
+void MonitorManager::slotStartMultiTrackMode()
+{
+    getAction(QStringLiteral("monitor_multitrack"))->setEnabled(false);
+    m_activeMultiTrack = pCore->window()->getCurrentTimeline()->controller()->activeTrack();
+    pCore->window()->getCurrentTimeline()->controller()->setMulticamIn(m_projectMonitor->position());
+}
+
+void MonitorManager::slotStopMultiTrackMode()
+{
+    if (m_activeMultiTrack == -1) {
+        return;
+    }
+    getAction(QStringLiteral("monitor_multitrack"))->setEnabled(true);
+    pCore->window()->getCurrentTimeline()->controller()->setMulticamIn(-1);
+    m_activeMultiTrack = -1;
+}
+
+void MonitorManager::slotPerformMultiTrackMode()
+{
+    if (m_activeMultiTrack == -1) {
+        return;
+    }
+    pCore->window()->getCurrentTimeline()->controller()->processMultitrackOperation(m_activeMultiTrack, pCore->window()->getCurrentTimeline()->controller()->multicamIn);
+    m_activeMultiTrack = pCore->window()->getCurrentTimeline()->controller()->activeTrack();
+    pCore->window()->getCurrentTimeline()->controller()->setMulticamIn(m_projectMonitor->position());
+}
+
 void MonitorManager::slotStart()
 {
     if (m_activeMonitor == m_clipMonitor) {
@@ -345,7 +397,7 @@ void MonitorManager::resetProfiles()
     }
     if (m_projectMonitor) {
         m_projectMonitor->resetProfile();
-    }
+    }  
 }
 
 void MonitorManager::resetConsumers(bool fullReset)
@@ -458,6 +510,10 @@ void MonitorManager::setupActions()
     });
     pCore->window()->addAction(QStringLiteral("monitor_multitrack"), m_multiTrack);
 
+    QAction *performMultiTrackOperation = new QAction(QIcon::fromTheme(QStringLiteral("media-playback-pause")), i18n("Perform Multitrack Operation"), this);
+    connect(performMultiTrackOperation, &QAction::triggered, this, &MonitorManager::slotPerformMultiTrackMode);
+    pCore->window()->addAction(QStringLiteral("perform_multitrack_mode"), performMultiTrackOperation);
+
     QAction *enableEditmode = new QAction(QIcon::fromTheme(QStringLiteral("transform-crop")), i18n("Show/Hide edit mode"), this);
     enableEditmode->setCheckable(true);
     enableEditmode->setChecked(KdenliveSettings::showOnMonitorScene());
@@ -519,6 +575,12 @@ void MonitorManager::setupActions()
 #endif
     pCore->window()->addAction(QStringLiteral("mlt_interpolation"), interpol);
     pCore->window()->actionCollection()->setShortcutsConfigurable(interpol, false);
+    
+    QAction *progressive = new QAction(QIcon::fromTheme(QString()), i18n("Progressive playback"), this);
+    connect(progressive, &QAction::triggered, this, &MonitorManager::slotProgressivePlay);
+    pCore->window()->addAction(QStringLiteral("mlt_progressive"), progressive);
+    progressive->setCheckable(true);
+    progressive->setChecked(KdenliveSettings::monitor_progressive());
 
     QAction *zoneStart = new QAction(QIcon::fromTheme(QStringLiteral("media-seek-backward")), i18n("Go to Zone Start"), this);
     connect(zoneStart, &QAction::triggered, this, &MonitorManager::slotZoneStart);
@@ -603,6 +665,23 @@ void MonitorManager::slotMuteCurrentMonitor(bool active)
     m_activeMonitor->mute(active);
 }
 
+void MonitorManager::slotProgressivePlay(bool active)
+{
+    if (pCore->getProjectProfile()->progressive()) {
+        // nothing to do
+        return;
+    }
+    KdenliveSettings::setMonitor_progressive(active);
+    if (m_clipMonitor) {
+        m_clipMonitor->resetConsumer(true);
+        m_clipMonitor->refreshMonitor(true);
+    }
+    if (m_projectMonitor) {
+        m_projectMonitor->resetConsumer(true);
+        m_projectMonitor->refreshMonitor(true);
+    }
+}
+
 Monitor *MonitorManager::clipMonitor()
 {
     return m_clipMonitor;
@@ -697,6 +776,25 @@ bool MonitorManager::isMultiTrack() const
     return false;
 }
 
+void MonitorManager::switchMultiTrackView(bool enable)
+{
+    if (isMultiTrack()) {
+        if (!enable) {
+            m_multiTrack->trigger();
+        }
+    } else if (enable) {
+        m_multiTrack->trigger();
+    }
+}
+
+bool MonitorManager::isTrimming() const
+{
+    if (m_projectMonitor && m_projectMonitor->m_trimmingbar) {
+        return m_projectMonitor->m_trimmingbar->isVisible();
+    }
+    return false;
+}
+
 void MonitorManager::updateBgColor()
 {
     if (m_projectMonitor) {
