@@ -222,7 +222,7 @@ void ProjectManager::newFile(QString profileName, bool showProjectSettings)
     pCore->bin()->setDocument(doc);
     m_project = doc;
     pCore->monitorManager()->activateMonitor(Kdenlive::ProjectMonitor);
-    updateTimeline(0);
+    updateTimeline(0, QString(), QString(), QDateTime(), 0);
     pCore->window()->connectDocument();
     pCore->mixer()->setModel(m_mainTimelineModel);
     bool disabled = m_project->getDocumentProperty(QStringLiteral("disabletimelineeffects")) == QLatin1String("1");
@@ -615,19 +615,15 @@ void ProjectManager::doOpenFile(const QUrl &url, KAutoSaveFile *stale)
 
     // Set default target tracks to upper audio / lower video tracks
     m_project = doc;
-    doc->loadDocumentGuides();
-    if (!updateTimeline(m_project->getDocumentProperty(QStringLiteral("position")).toInt())) {
+    m_project->loadDocumentGuides();
+    QDateTime documentDate = QFileInfo(m_project->url().toLocalFile()).lastModified();
+    if (!updateTimeline(m_project->getDocumentProperty(QStringLiteral("position")).toInt(), m_project->getDocumentProperty(QStringLiteral("previewchunks")), m_project->getDocumentProperty(QStringLiteral("dirtypreviewchunks")), documentDate, m_project->getDocumentProperty(QStringLiteral("disablepreview")).toInt())) {
         delete m_progressDialog;
         m_progressDialog = nullptr;
         return;
     }
     pCore->window()->connectDocument();
     pCore->mixer()->setModel(m_mainTimelineModel);
-    QDateTime documentDate = QFileInfo(m_project->url().toLocalFile()).lastModified();
-    pCore->window()->getMainTimeline()->controller()->loadPreview(m_project->getDocumentProperty(QStringLiteral("previewchunks")),
-                                                                  m_project->getDocumentProperty(QStringLiteral("dirtypreviewchunks")), documentDate,
-                                                                  m_project->getDocumentProperty(QStringLiteral("disablepreview")).toInt());
-
     emit docOpened(m_project);
     pCore->displayMessage(QString(), OperationCompletedMessage, 100);
     if (openBackup) {
@@ -929,7 +925,7 @@ void ProjectManager::slotMoveFinished(KJob *job)
     }
 }
 
-bool ProjectManager::updateTimeline(int pos)
+bool ProjectManager::updateTimeline(int pos, const QString &chunks, const QString &dirty, const QDateTime &documentDate, int enablePreview)
 {
     pCore->taskManager.slotCancelJobs();
     pCore->window()->getMainTimeline()->loading = true;
@@ -956,14 +952,16 @@ bool ProjectManager::updateTimeline(int pos)
         return false;
     }
     m_mainTimelineModel = TimelineItemModel::construct(pCore->getProjectProfile(), m_project->getGuideModel(), m_project->commandStack());
-    // Add snap point at projec start
+    // Add snap point at project start
     m_mainTimelineModel->addSnap(0);
     pCore->window()->getMainTimeline()->setModel(m_mainTimelineModel, pCore->monitorManager()->projectMonitor()->getControllerProxy());
     bool projectErrors = false;
-    if (!constructTimelineFromMelt(m_mainTimelineModel, tractor, m_progressDialog, m_project->modifiedDecimalPoint(), &projectErrors)) {
+    if (!constructTimelineFromMelt(m_mainTimelineModel, tractor, m_progressDialog, m_project->modifiedDecimalPoint(), chunks, dirty, documentDate, enablePreview, &projectErrors)) {
         //TODO: act on project load failure
         qDebug()<<"// Project failed to load!!";
     }
+    // Free memory used by original playlist
+    xmlProd.reset(nullptr);
     const QString groupsData = m_project->getDocumentProperty(QStringLiteral("groups"));
     // update track compositing
     int compositing = pCore->currentDoc()->getDocumentProperty(QStringLiteral("compositing"), QStringLiteral("2")).toInt();
@@ -1158,6 +1156,13 @@ void ProjectManager::saveWithUpdatedProfile(const QString &updatedProfile)
     for (int i = 0; i < producers.count(); ++i) {
         QDomElement e = producers.at(i).toElement();
         bool ok;
+        if (Xml::getXmlProperty(e, QStringLiteral("mlt_service")) == QLatin1String("qimage") && Xml::hasXmlProperty(e, QStringLiteral("ttl"))) {
+            // Slideshow, duration is frame based, should be calculated again
+            Xml::setXmlProperty(e, QStringLiteral("length"), QStringLiteral("0"));
+            Xml::removeXmlProperty(e, QStringLiteral("kdenlive:duration"));
+            e.setAttribute(QStringLiteral("out"), -1);
+            continue;
+        }
         int length = Xml::getXmlProperty(e, QStringLiteral("length")).toInt(&ok);
         if (ok && length > 0) {
             // calculate updated length
