@@ -158,6 +158,7 @@ protected:
        @param in is the new starting on the clip
        @param out is the new ending on the clip
        @param right is true if we change the right side of the clip, false otherwise
+       @param hasMix is true if we change the right side of the clip, false otherwise
     */
     Fun requestClipResize_lambda(int clipId, int in, int out, bool right, bool hasMix = false);
 
@@ -320,6 +321,8 @@ protected:
     bool hasStartMix(int cid) const;
     /** @brief Returns true if this clip has a mix at end */
     bool hasEndMix(int cid) const;
+    /** @brief Returns the cid of the second partner or -1 if the given clip has no end mix */
+    int getSecondMixPartner(int cid) const;
     /** @brief Returns the cut position if the composition is over a cut between 2 clips, -1 otherwise
     */
     int isOnCut(int cid);
