@@ -1,22 +1,9 @@
-/***************************************************************************
- *   copyright (C) 2008 by Marco Gittler (g.marco@freenet.de)                                 *
- *   Copyright (C) 2008 by Jean-Baptiste Mardelle (jb@kdenlive.org)        *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Marco Gittler <g.marco@freenet.de>
+    SPDX-FileCopyrightText: 2008 Jean-Baptiste Mardelle <jb@kdenlive.org>
+
+SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "graphicsscenerectmove.h"
 #include "titler/gradientwidget.h"
@@ -413,6 +400,12 @@ QVariant MyTextItem::itemChange(GraphicsItemChange change, const QVariant &value
             int gridSize = customScene->gridSize();
             int xV = (newPos.x() / gridSize) * gridSize;
             int yV = (newPos.y() / gridSize) * gridSize;
+            if (QApplication::keyboardModifiers() == Qt::ShiftModifier) {
+                xV = pos().x();
+            }
+            if (QApplication::keyboardModifiers() == (Qt::ShiftModifier | Qt::AltModifier)) {
+                yV = pos().y();
+            }
             newPos = QPoint(xV, yV);
         }
         return newPos;
@@ -477,6 +470,12 @@ QVariant MyRectItem::itemChange(GraphicsItemChange change, const QVariant &value
             int gridSize = customScene->gridSize();
             int xV = (newPos.x() / gridSize) * gridSize;
             int yV = (newPos.y() / gridSize) * gridSize;
+            if (QApplication::keyboardModifiers() == Qt::ShiftModifier) {
+                xV = pos().x();
+            }
+            if (QApplication::keyboardModifiers() == (Qt::ShiftModifier | Qt::AltModifier)) {
+                yV = pos().y();
+            }
             newPos = QPoint(xV, yV);
         }
         return newPos;
@@ -511,6 +510,12 @@ QVariant MyEllipseItem::itemChange(GraphicsItemChange change, const QVariant &va
             int gridSize = customScene->gridSize();
             int xV = (newPos.x() / gridSize) * gridSize;
             int yV = (newPos.y() / gridSize) * gridSize;
+            if (QApplication::keyboardModifiers() == Qt::ShiftModifier) {
+                xV = pos().x();
+            }
+            if (QApplication::keyboardModifiers() == (Qt::ShiftModifier | Qt::AltModifier)) {
+                yV = pos().y();
+            }
             newPos = QPoint(xV, yV);
         }
         return newPos;
@@ -535,6 +540,12 @@ QVariant MyPixmapItem::itemChange(GraphicsItemChange change, const QVariant &val
             int gridSize = customScene->gridSize();
             int xV = (newPos.x() / gridSize) * gridSize;
             int yV = (newPos.y() / gridSize) * gridSize;
+            if (QApplication::keyboardModifiers() == Qt::ShiftModifier) {
+                xV = pos().x();
+            }
+            if (QApplication::keyboardModifiers() == (Qt::ShiftModifier | Qt::AltModifier)) {
+                yV = pos().y();
+            }
             newPos = QPoint(xV, yV);
         }
         return newPos;
@@ -559,6 +570,12 @@ QVariant MySvgItem::itemChange(GraphicsItemChange change, const QVariant &value)
             int gridSize = customScene->gridSize();
             int xV = (newPos.x() / gridSize) * gridSize;
             int yV = (newPos.y() / gridSize) * gridSize;
+            if (QApplication::keyboardModifiers() == Qt::ShiftModifier) {
+                xV = pos().x();
+            }
+            if (QApplication::keyboardModifiers() == (Qt::ShiftModifier | Qt::AltModifier)) {
+                yV = pos().y();
+            }
             newPos = QPoint(xV, yV);
         }
         return newPos;
@@ -628,32 +645,32 @@ void GraphicsSceneRectMove::keyPressEvent(QKeyEvent *keyEvent)
     }
     switch (keyEvent->key()) {
     case Qt::Key_Left:
-        for (QGraphicsItem *qgi : selectedItems()) {
+        foreach (QGraphicsItem *qgi, selectedItems()) {
             qgi->moveBy(-diff, 0);
         }
         emit itemMoved();
         break;
     case Qt::Key_Right:
-        for (QGraphicsItem *qgi : selectedItems()) {
+        foreach (QGraphicsItem *qgi, selectedItems()) {
             qgi->moveBy(diff, 0);
         }
         emit itemMoved();
         break;
     case Qt::Key_Up:
-        for (QGraphicsItem *qgi : selectedItems()) {
+        foreach (QGraphicsItem *qgi, selectedItems()) {
             qgi->moveBy(0, -diff);
         }
         emit itemMoved();
         break;
     case Qt::Key_Down:
-        for (QGraphicsItem *qgi : selectedItems()) {
+        foreach (QGraphicsItem *qgi, selectedItems()) {
             qgi->moveBy(0, diff);
         }
         emit itemMoved();
         break;
     case Qt::Key_Delete:
     case Qt::Key_Backspace:
-        for (QGraphicsItem *qgi : selectedItems()) {
+        foreach (QGraphicsItem *qgi, selectedItems()) {
             if (qgi->data(-1).toInt() == -1) {
                 continue;
             }
