@@ -1,23 +1,7 @@
-/***************************************************************************
- *   Copyright (C) 2017 by Nicolas Carion                                  *
- *   This file is part of Kdenlive. See www.kdenlive.org.                  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) version 3 or any later version accepted by the       *
- *   membership of KDE e.V. (or its successor approved  by the membership  *
- *   of KDE e.V.), which shall act as a proxy defined in Section 14 of     *
- *   version 3 of the license.                                             *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2017 Nicolas Carion
+    SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #ifndef TRANSITIONLISTWIDGET_H
 #define TRANSITIONLISTWIDGET_H
@@ -38,6 +22,7 @@ public:
     TransitionListWidget(QWidget *parent = Q_NULLPTR);
     ~TransitionListWidget() override;
     void setFilterType(const QString &type);
+    bool isAudio(const QString &assetId) const override;
     /** @brief Return mime type used for drag and drop. It will be kdenlive/composition
      or kdenlive/transition*/
     QString getMimeType(const QString &assetId) const override;
@@ -47,7 +32,6 @@ public:
     void editCustomAsset(const QModelIndex &index) override;
 private:
     TransitionListWidgetProxy *m_proxy;
-    int getNewStuff(const QString &configFile);
 
 signals:
     void reloadFavorites();
