@@ -1,29 +1,14 @@
-/***************************************************************************
- *   Copyright (C) 2017 by Nicolas Carion                                  *
- *   This file is part of Kdenlive. See www.kdenlive.org.                  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) version 3 or any later version accepted by the       *
- *   membership of KDE e.V. (or its successor approved  by the membership  *
- *   of KDE e.V.), which shall act as a proxy defined in Section 14 of     *
- *   version 3 of the license.                                             *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2017 Nicolas Carion
+    SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "mixstackview.hpp"
 #include "assets/keyframes/model/keyframemodellist.hpp"
 #include "assets/model/assetparametermodel.hpp"
 #include "core.h"
 #include "monitor/monitor.h"
+#include "widgets/positionwidget.h"
 #include "timecodedisplay.h"
 
 #include <QComboBox>
@@ -37,8 +22,12 @@
 MixStackView::MixStackView(QWidget *parent)
     : AssetParameterView(parent)
 {
+    // Position widget
+    m_position = new PositionWidget(i18n("Position"), 0, 0, 0, pCore->timecode()); // TimecodeDisplay(pCore->timecode(), this);
+    // Duration widget
     m_durationLayout = new QHBoxLayout;
     m_duration = new TimecodeDisplay(pCore->timecode(), this);
+    m_duration->setRange(1, -1);
     m_durationLayout->addWidget(new QLabel(i18n("Duration:")));
     m_durationLayout->addWidget(m_duration);
     m_alignLeft = new QToolButton(this);
@@ -64,6 +53,12 @@ MixStackView::MixStackView(QWidget *parent)
     m_durationLayout->addWidget(m_alignCenter);
     m_durationLayout->addWidget(m_alignLeft);
     connect(m_duration, &TimecodeDisplay::timeCodeUpdated, this, &MixStackView::updateDuration);
+    connect(m_position, &PositionWidget::valueChanged, this, &MixStackView::updatePosition);
+    connect(this, &AssetParameterView::seekToPos, [this](int pos) {
+        // at this point, the effects returns a pos relative to the clip. We need to convert it to a global time
+        int clipIn = pCore->getItemPosition(m_model->getOwnerId());
+        emit seekToTransPos(pos + clipIn);
+    });
 }
 
 void MixStackView::setModel(const std::shared_ptr<AssetParameterModel> &model, QSize frameSize, bool addSpacer)
@@ -74,21 +69,29 @@ void MixStackView::setModel(const std::shared_ptr<AssetParameterModel> &model, Q
     if (kfr) {
         connect(kfr.get(), &KeyframeModelList::modelChanged, this, &AssetParameterView::slotRefresh);
     }
-    connect(this, &AssetParameterView::seekToPos, [this](int pos) {
-        // at this point, the effects returns a pos relative to the clip. We need to convert it to a global time
-        int clipIn = 0; //pCore->getItemPosition(m_model->getOwnerId());
-        emit seekToTransPos(pos + clipIn);
-    });
     emit initKeyframeView(true);
     pCore->getMonitor(m_model->monitorId)->slotShowEffectScene(needsMonitorEffectScene());
 
-    if (m_model->rowCount() > 0) {
-        QSignalBlocker bk0(m_duration);
-        m_duration->setValue(m_model->data(m_model->index(0, 0), AssetParameterModel::ParentDurationRole).toInt());
-        connect(m_model.get(), &AssetParameterModel::dataChanged, this, &MixStackView::durationChanged);
-    }
-    int mainClipId = stackOwner().second;
-    MixAlignment align = pCore->getMixAlign(mainClipId);
+    const QSignalBlocker bk0(m_duration);
+    const QSignalBlocker bk1(m_position);
+    int duration = m_model->data(m_model->index(0, 0), AssetParameterModel::ParentDurationRole).toInt();
+    m_duration->setValue(duration + 1);
+    m_position->updateTimecodeFormat();
+    m_position->setRange(0, duration);
+    m_position->setPosition(duration - pCore->getMixCutPos(stackOwner().second));
+    connect(m_model.get(), &AssetParameterModel::dataChanged, this, &MixStackView::durationChanged);
+
+    // The layout is handled by AssetParameterView, so we can only add our custom stuff later here
+    m_lay->addLayout(m_durationLayout);
+    m_lay->addWidget(m_position);
+    m_lay->addStretch(10);
+    checkAlignment();
+    slotRefresh();
+}
+
+void MixStackView::checkAlignment()
+{
+    MixAlignment align = pCore->getMixAlign(stackOwner().second);
     QSignalBlocker bk1(m_alignLeft);
     QSignalBlocker bk2(m_alignRight);
     QSignalBlocker bk3(m_alignCenter);
@@ -109,17 +112,23 @@ void MixStackView::setModel(const std::shared_ptr<AssetParameterModel> &model, Q
             // No alignment
             break;
     }
-    m_model->data(m_model->index(0, 0), AssetParameterModel::ParentDurationRole).toInt();
-    m_lay->addLayout(m_durationLayout);
-    m_lay->addStretch(10);
-    slotRefresh();
 }
 
 void MixStackView::durationChanged(const QModelIndex &, const QModelIndex &, const QVector<int> &roles)
 {
     if (roles.contains(AssetParameterModel::ParentDurationRole)) {
+        int duration = m_model->data(m_model->index(0, 0), AssetParameterModel::ParentDurationRole).toInt();
+        int mixCutPos = pCore->getMixCutPos(stackOwner().second);
+        if (duration + 1 == m_duration->getValue() && mixCutPos == m_position->getPosition()) {
+            // No change
+            return;
+        }
         QSignalBlocker bk1(m_duration);
-        m_duration->setValue(m_model->data(m_model->index(0, 0), AssetParameterModel::ParentDurationRole).toInt());
+        QSignalBlocker bk2(m_position);
+        m_duration->setValue(duration + 1);
+        m_position->setRange(0, duration);
+        m_position->setPosition(mixCutPos);
+        checkAlignment();
     }
 }
 
@@ -139,7 +148,12 @@ MixAlignment MixStackView::alignment() const
 
 void MixStackView::updateDuration()
 {
-    pCore->resizeMix(stackOwner().second, m_duration->getValue(), alignment());
+    pCore->resizeMix(stackOwner().second, m_duration->getValue() - 1, alignment());
+}
+
+void MixStackView::updatePosition()
+{
+    pCore->resizeMix(stackOwner().second, m_duration->getValue() - 1, MixAlignment::AlignNone, m_position->getPosition());
 }
 
 void MixStackView::slotAlignLeft()
@@ -149,7 +163,7 @@ void MixStackView::slotAlignLeft()
     }
     m_alignRight->setChecked(false);
     m_alignCenter->setChecked(false);
-    pCore->resizeMix(stackOwner().second, m_duration->getValue(), MixAlignment::AlignLeft);
+    pCore->resizeMix(stackOwner().second, m_duration->getValue() - 1, MixAlignment::AlignLeft);
 }
 
 void MixStackView::slotAlignRight()
@@ -159,7 +173,7 @@ void MixStackView::slotAlignRight()
     }
     m_alignLeft->setChecked(false);
     m_alignCenter->setChecked(false);
-    pCore->resizeMix(stackOwner().second, m_duration->getValue(), MixAlignment::AlignRight);
+    pCore->resizeMix(stackOwner().second, m_duration->getValue() - 1, MixAlignment::AlignRight);
 }
 
 void MixStackView::slotAlignCenter()
@@ -169,7 +183,7 @@ void MixStackView::slotAlignCenter()
     }
     m_alignLeft->setChecked(false);
     m_alignRight->setChecked(false);
-    pCore->resizeMix(stackOwner().second, m_duration->getValue(), MixAlignment::AlignCenter);
+    pCore->resizeMix(stackOwner().second, m_duration->getValue() - 1, MixAlignment::AlignCenter);
 }
 
 void MixStackView::unsetModel()
@@ -177,6 +191,7 @@ void MixStackView::unsetModel()
     if (m_model) {
         m_model->setActive(false);
         m_lay->removeItem(m_durationLayout);
+        m_lay->removeWidget(m_position);
         auto kfr = m_model->getKeyframeModel();
         if (kfr) {
             disconnect(kfr.get(), &KeyframeModelList::modelChanged, this, &AssetParameterView::slotRefresh);
