@@ -1,23 +1,7 @@
-/***************************************************************************
- *   Copyright (C) 2017 by Nicolas Carion                                  *
- *   This file is part of Kdenlive. See www.kdenlive.org.                  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) version 3 or any later version accepted by the       *
- *   membership of KDE e.V. (or its successor approved  by the membership  *
- *   of KDE e.V.), which shall act as a proxy defined in Section 14 of     *
- *   version 3 of the license.                                             *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2017 Nicolas Carion
+    SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "transitionstackview.hpp"
 #include "assets/keyframes/model/keyframemodellist.hpp"
@@ -35,6 +19,11 @@
 TransitionStackView::TransitionStackView(QWidget *parent)
     : AssetParameterView(parent)
 {
+    connect(this, &AssetParameterView::seekToPos, [this](int pos) {
+        // at this point, the effects returns a pos relative to the clip. We need to convert it to a global time
+        int clipIn = pCore->getItemPosition(m_model->getOwnerId());
+        emit seekToTransPos(pos + clipIn);
+    });
 }
 
 void TransitionStackView::refreshTracks()
@@ -77,11 +66,6 @@ void TransitionStackView::setModel(const std::shared_ptr<AssetParameterModel> &m
     }
     connect(model.get(), &AssetParameterModel::compositionTrackChanged, this, &TransitionStackView::checkCompoTrack);
     connect(m_trackBox, SIGNAL(currentIndexChanged(int)), this, SLOT(updateTrack(int)));
-    connect(this, &AssetParameterView::seekToPos, [this](int pos) {
-        // at this point, the effects returns a pos relative to the clip. We need to convert it to a global time
-        int clipIn = 0;//pCore->getItemPosition(m_model->getOwnerId());
-        emit seekToTransPos(pos + clipIn);
-    });
     emit initKeyframeView(true);
     pCore->getMonitor(m_model->monitorId)->slotShowEffectScene(needsMonitorEffectScene());
     m_lay->addStretch(10);
