@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2010 by Till Theato (root@ttill.de)                     *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Till Theato <root@ttill.de>
+
+SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "colorpickerwidget.h"
 
@@ -125,7 +112,7 @@ void ColorPickerWidget::slotGetAverageColor()
     Window root = RootWindow(QX11Info::display(), QX11Info::appScreen());
     m_image = XGetImage(QX11Info::display(), root, m_grabRect.x(), m_grabRect.y(), m_grabRect.width(), m_grabRect.height(), -1, ZPixmap);
 #else
-    for (QScreen *screen : QGuiApplication::screens()) {
+    foreach (QScreen *screen, QGuiApplication::screens()) {
         QRect screenRect = screen->geometry();
         if (screenRect.contains(m_grabRect.topLeft())) {
             m_image = screen->grabWindow(0, m_grabRect.x() - screenRect.x(), m_grabRect.y() - screenRect.y(), m_grabRect.width(), m_grabRect.height()).toImage();
@@ -266,7 +253,7 @@ QColor ColorPickerWidget::grabColor(const QPoint &p, bool destroyImage)
 #else
     Q_UNUSED(destroyImage)
     if (m_image.isNull()) {
-        for (QScreen *screen : QGuiApplication::screens()) {
+        foreach (QScreen *screen, QGuiApplication::screens()) {
             QRect screenRect = screen->geometry();
             if (screenRect.contains(p)) {
                 QPixmap pm = screen->grabWindow(0, p.x() - screenRect.x(), p.y() - screenRect.y(), 1, 1);
