@@ -30,7 +30,7 @@ public:
      * @param useRatioLock When true, width/height will keep the profile's aspect ratio on resize
      */
     explicit GeometryWidget(Monitor *monitor, QPair<int, int> range, const QRect &rect, double opacity, const QSize frameSize, bool useRatioLock,
-                            bool useOpacity, bool percentOpacity, QWidget *parent = nullptr);
+                            bool useOpacity, QWidget *parent = nullptr);
     void setValue(const QRect r, double opacity = 1);
     void connectMonitor(bool activate);
 
